==> claromentis-knowledgebase-4.1.6-14478180.zip: classes/KBCategoryRestFilter.php <==
<?php
namespace Claromentis\Knowledgebase;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"] ?: array()) + array();





class KBCategoryRestFilter
{
    protected $category_id;
    protected $subcategory_id;
    protected $parent_id;
    protected $category_name;
    protected $subcategory_name;
    protected $is_collection;
    protected $collection_name;
    protected $apply_perms;
    public function GetCategoryId()
    {
        return $this->category_id;
    }
    public function SetCategoryId($_0ea4e32b57963ac0cb3057e03e9aef64)
    {
        $this->category_id = $_0ea4e32b57963ac0cb3057e03e9aef64;
        return $this;
    }
    public function GetSubcategoryId()
    {
        return $this->subcategory_id;
    }
    public function SetSubcategoryId($_0ea4e32b57963ac0cb3057e03e9aef64)
    {
        $this->subcategory_id = $_0ea4e32b57963ac0cb3057e03e9aef64;
        return $this;
    }
    public function GetParentId()
    {
        return $this->parent_id;
    }
    public function SetParentId($_0ea4e32b57963ac0cb3057e03e9aef64)
    {
        $this->parent_id = $_0ea4e32b57963ac0cb3057e03e9aef64;
        return $this;
    }
    public function GetCategoryName()
    {
        return $this->category_name;
    }
    public function SetCategoryName($_8dabb06efc95df4cff7c4afe91857b53)
    {
        $this->category_name = $_8dabb06efc95df4cff7c4afe91857b53;
        return $this;
    }
    public function GetSubcategoryName()
    {
        return $this->subcategory_name;
    }
    public function SetSubcategoryName($_8dabb06efc95df4cff7c4afe91857b53)
    {
        $this->subcategory_name = $_8dabb06efc95df4cff7c4afe91857b53;
        return $this;
    }
    public function SetAsCollection($_2a7aff49a6a781940a1e50a0d332b2a6)
    {
        $this->is_collection = (bool) $_2a7aff49a6a781940a1e50a0d332b2a6;
        return $this;
    }
    public function IsCollection()
    {
        return $this->is_collection;
    }
    public function SetCollectionName($_6a8a63cb60573aaa26a8c729289c3f35)
    {
        $this->collection_name = $_6a8a63cb60573aaa26a8c729289c3f35;
        return $this;
    }
    public function GetCollectionName()
    {
        return $this->collection_name;
    }
    public function SetApplyPerms()
    {
        $this->apply_perms = true;
        return $this;
    }
    public function GetApplyPerms()
    {
        return $this->apply_perms;
    }
}

==> claromentis-knowledgebase-5.0.8-499ab622.zip: classes/KBCategoryRestFilter.php <==
<?php
namespace Claromentis\Knowledgebase;

$GLOBALS["__65da1b1" . "ec2d6653e" . "8a0ab7848" . "e536215"] = (@$GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"] ?: array()) + array();





class KBCategoryRestFilter
{
    protected $category_id;
    protected $subcategory_id;
    protected $parent_id;
    protected $category_name;
    protected $subcategory_name;
    protected $is_collection;
    protected $collection_name;
    protected $apply_perms;
    public function GetCategoryId()
    {
        return $this->category_id;
    }
    public function SetCategoryId($_0ea4e32b57963ac0cb3057e03e9aef64)
    {
        $this->category_id = $_0ea4e32b57963ac0cb3057e03e9aef64;
        return $this;
    }
    public function GetSubcategoryId()
    {
        return $this->subcategory_id;
    }
    public function SetSubcategoryId($_0ea4e32b57963ac0cb3057e03e9aef64)
    {
        $this->subcategory_id = $_0ea4e32b57963ac0cb3057e03e9aef64;
        return $this;
    }
    public function GetParentId()
    {
        return $this->parent_id;
    }
    public function SetParentId($_0ea4e32b57963ac0cb3057e03e9aef64)
    {
        $this->parent_id = $_0ea4e32b57963ac0cb3057e03e9aef64;
        return $this;
    }
    public function GetCategoryName()
    {
        return $this->category_name;
    }
    public function SetCategoryName($_8dabb06efc95df4cff7c4afe91857b53)
    {
        $this->category_name = $_8dabb06efc95df4cff7c4afe91857b53;
        return $this;
    }
    public function GetSubcategoryName()
    {
        return $this->subcategory_name;
    }
    public function SetSubcategoryName($_8dabb06efc95df4cff7c4afe91857b53)
    {
        $this->subcategory_name = $_8dabb06efc95df4cff7c4afe91857b53;
        return $this;
    }
    public function SetAsCollection($_2a7aff49a6a781940a1e50a0d332b2a6)
    {
        $this->is_collection = (bool) $_2a7aff49a6a781940a1e50a0d332b2a6;
        return $this;
    }
    public function IsCollection()
    {
        return $this->is_collection;
    }
    public function SetCollectionName($_6a8a63cb60573aaa26a8c729289c3f35)
    {
        $this->collection_name = $_6a8a63cb60573aaa26a8c729289c3f35;
        return $this;
    }
    public function GetCollectionName()
    {
        return $this->collection_name;
    }
    public function SetApplyPerms()
    {
        $this->apply_perms = true;
        return $this;
    }
    public function GetApplyPerms()
    {
        return $this->apply_perms;
    }
}
